@@ -34,7 +34,7 @@ License:
 ::
 
 
-    Copyright 2017, 2018, 2019, 2020 Nissar Chababy
+    Copyright 2017, 2018, 2019, 2020, 2021 Nissar Chababy
 
     Licensed under the Apache License, Version 2.0 (the "License");
     you may not use this file except in compliance with the License.
@@ -146,6 +146,11 @@ else:  # pragma: no cover
             #   * `APPDATA` is not into the environnement variables.
             # We set the current directory as the directory we are working with.
             CONFIG_DIRECTORY = helpers.Directory.get_current(with_end_sep=True)
+    else:
+        # We are under somethint we don't know about.
+
+        # We set the current directory as the directory we are working with.
+        CONFIG_DIRECTORY = helpers.Directory.get_current(with_end_sep=True)
 
     if not CONFIG_DIRECTORY.endswith(directory_separator):
         # If the directory we are working with does not ends with the directory
@@ -259,6 +264,7 @@ def test(subject, complete=False, config=None):  # pragma: no cover
                 "dns_lookup": [],
                 "domain_syntax_validation": None,
                 "expiration_date": None,
+                "given": None,
                 "http_status_code": None,
                 "ipv4_range_syntax_validation": None,
                 "ipv4_syntax_validation": None,
@@ -324,6 +330,7 @@ def url_test(subject, complete=False, config=None):  # pragma: no covere
                 "dns_lookup": [],
                 "domain_syntax_validation": None,
                 "expiration_date": None,
+                "given": None,
                 "http_status_code": None,
                 "ipv4_range_syntax_validation": None,
                 "ipv4_syntax_validation": None,
