@@ -35,7 +35,7 @@ License:
 ::
 
 
-    Copyright 2017, 2018, 2019, 2020 Nissar Chababy
+    Copyright 2017, 2018, 2019, 2020, 2021 Nissar Chababy
 
     Licensed under the Apache License, Version 2.0 (the "License");
     you may not use this file except in compliance with the License.
@@ -58,13 +58,20 @@ class Platform:  # pragma: no cover
     Provides an easy way to get the current platform.
     """
 
-    WINDOWS = ["windows", "cygwin", "cygwin_nt-10.0"]
+    WINDOWS = ["windows"]
     """
     Provides the list of supported windows platform.
 
     :type: list
     """
 
+    CYGWIN = ["cygwin", "cygwin_nt-10.0"]
+    """
+    Provides the list of supporter cygwin platform.
+
+    :type: lsit
+    """
+
     UNIX = ["linux", "darwin"]
     """
     Provides the list of supported unix platform.
@@ -89,6 +96,18 @@ class Platform:  # pragma: no cover
 
         return system().lower()
 
+    @classmethod
+    def is_cygwin(cls):
+        """
+        Checks if the current platform is in our cygwin list.
+
+        :rtype: bool
+        """
+
+        current_platform = cls.get()
+
+        return any(x in current_platform for x in cls.CYGWIN)
+
     @classmethod
     def is_windows(cls):
         """
@@ -97,7 +116,7 @@ class Platform:  # pragma: no cover
         :rtype: bool
         """
 
-        return cls.get() in cls.WINDOWS
+        return cls.get() in cls.WINDOWS or cls.is_cygwin()
 
     @classmethod
     def is_unix(cls):
