@@ -35,7 +35,7 @@ License:
 ::
 
 
-    Copyright 2017, 2018, 2019, 2020 Nissar Chababy
+    Copyright 2017, 2018, 2019, 2020, 2021 Nissar Chababy
 
     Licensed under the Apache License, Version 2.0 (the "License");
     you may not use this file except in compliance with the License.
@@ -91,13 +91,6 @@ class Check:
     def __init__(self, subject):
         self.subject = subject
 
-        if (
-            self.subject.startswith("*.")
-            and PyFunceble.CONFIGURATION.wildcard
-            and PyFunceble.CONFIGURATION.syntax
-        ):
-            self.subject = self.subject[2:]
-
     def is_url(
         self, return_base=False, return_formatted=False
     ):  # pylint: disable=too-many-branches
