@@ -36,7 +36,7 @@ License:
 ::
 
 
-    Copyright 2017, 2018, 2019, 2020 Nissar Chababy
+    Copyright 2017, 2018, 2019, 2020, 2021 Nissar Chababy
 
     Licensed under the Apache License, Version 2.0 (the "License");
     you may not use this file except in compliance with the License.
@@ -303,6 +303,18 @@ def tool():  # pragma: no cover pylint: disable=too-many-branches,too-many-state
                     ),
                 )
 
+                test_control.add_argument(
+                    "--rpz",
+                    action="store_true",
+                    help="Switch the value of the RPZ policies test.\n\n"
+                    "When used, RPZ policies will be properly tested.\n\n %s"
+                    % (
+                        current_value_format
+                        + repr(PyFunceble.CONFIGURATION.rpz)
+                        + Style.RESET_ALL
+                    ),
+                )
+
                 test_control.add_argument(
                     "--shadow-file",
                     "--shadow",
@@ -378,9 +390,7 @@ def tool():  # pragma: no cover pylint: disable=too-many-branches,too-many-state
                     "--wildcard",
                     action="store_true",
                     help="Switch the value of the wildcards test.\n\n"
-                    "When used, wildcards will be proprely tested.\n\n"
-                    f"{Fore.MAGENTA}{Style.BRIGHT}Warning: This is not taken in consideration if the "
-                    f"'--syntax' argument is not given.{Style.RESET_ALL} %s"
+                    "When used, wildcards will be properly tested. %s"
                     % (
                         current_value_format
                         + repr(PyFunceble.CONFIGURATION.wildcard)
@@ -1097,6 +1107,9 @@ def tool():  # pragma: no cover pylint: disable=too-many-branches,too-many-state
                 if args.reputation:
                     PyFunceble.CONFIGURATION.reputation = preset.switch("reputation")
 
+                if args.rpz:
+                    PyFunceble.CONFIGURATION.rpz = preset.switch("rpz")
+
                 if args.shadow_file:
                     PyFunceble.CONFIGURATION.shadow_file = preset.switch("shadow_file")
 
