@@ -35,7 +35,7 @@ License:
 ::
 
 
-    Copyright 2017, 2018, 2019, 2020 Nissar Chababy
+    Copyright 2017, 2018, 2019, 2020, 2021 Nissar Chababy
 
     Licensed under the Apache License, Version 2.0 (the "License");
     you may not use this file except in compliance with the License.
@@ -55,3 +55,6 @@ from .digit2digits import Digit2Digits
 from .file import File
 from .internal_url import InternalUrl
 from .month import Month
+from .rpz2subject import RPZ2Subject
+from .rpz_file import RPZFile
+from .wildcard2subject import Wildcard2Subject
