@@ -35,7 +35,7 @@ License:
 ::
 
 
-    Copyright 2017, 2018, 2019, 2020 Nissar Chababy
+    Copyright 2017, 2018, 2019, 2020, 2021 Nissar Chababy
 
     Licensed under the Apache License, Version 2.0 (the "License");
     you may not use this file except in compliance with the License.
@@ -50,11 +50,13 @@ License:
     limitations under the License.
 """
 
+
 import sys
 from datetime import datetime
 from os import sep as directory_separator
 from os import walk
 from random import choice
+from string import ascii_lowercase
 
 from colorama import Fore, Style
 from sqlalchemy.orm.exc import NoResultFound
@@ -90,13 +92,11 @@ class CLICore:
         Provides the list of up statuses.
         """
 
-        list_of_up_statuses = PyFunceble.STATUS.list.up
-        list_of_up_statuses.extend(PyFunceble.STATUS.list.valid)
-        list_of_up_statuses.extend(PyFunceble.STATUS.list.sane)
-
-        list_of_up_statuses.extend([x.upper() for x in list_of_up_statuses])
-
-        return list_of_up_statuses
+        return [
+            PyFunceble.STATUS.official.up,
+            PyFunceble.STATUS.official.valid,
+            PyFunceble.STATUS.official.sane,
+        ]
 
     @classmethod
     def sort_generated_files(cls):  # pragma: no cover
@@ -185,15 +185,17 @@ class CLICore:
             if not filename:
                 filename = "simple"
 
-            status_input = output.copy()
+            output["tested"] = output["given"]
 
-            undesirable_status = ["dns_lookup", "whois_record", "whois_server"]
+            undesirable_status = ["dns_lookup", "whois_record", "whois_server", "given"]
 
             for index in undesirable_status:
-                del status_input[index]
+                del output[index]
 
             with session.Session() as db_session:
                 # pylint: disable=no-member
+                status_found_in_db = False
+
                 try:
                     file = db_session.query(File).filter(File.path == filename).one()
                 except NoResultFound:
@@ -203,26 +205,22 @@ class CLICore:
                     db_session.commit()
                     db_session.refresh(file)
 
-            with session.Session() as db_session:
-                # pylint: disable=no-member
                 try:
-                    status = (
-                        db_session.query(Status)
-                        .filter(Status.file_id == file.id)
-                        .filter(Status.tested == status_input["tested"])
-                        .one()
-                    )
+                    status = file.subjects.filter(
+                        Status.tested == output["tested"]
+                    ).one()
+                    status_found_in_db = True
                 except NoResultFound:
                     status = Status(file_id=file.id)
 
-            for index, value in status_input.items():
-                setattr(status, index, value)
+                for index, value in output.items():
+                    setattr(status, index, value)
 
-            status.test_completed = True
+                status.test_completed = True
+
+                if not status_found_in_db:
+                    file.subjects.append(status)
 
-            with session.Session() as db_session:
-                # pylint: disable=no-member
-                db_session.add(status)
                 db_session.commit()
 
             PyFunceble.LOGGER.debug(f"Saved into database:\n{output}")
@@ -421,7 +419,7 @@ class CLICore:
         # We initiate the link to the upstream version file.
         # It is hard coded because we may not have the chance to have the
         # configuration file everytime we need it.
-        upstream_link = "https://raw.githubusercontent.com/funilrys/PyFunceble/master/version.yaml"  # pylint: disable=line-too-long
+        upstream_link = "https://raw.githubusercontent.com/funilrys/PyFunceble/3.x/version.yaml"  # pylint: disable=line-too-long
 
         upstream_link = PyFunceble.converter.InternalUrl(upstream_link).get_converted()
 
@@ -494,12 +492,10 @@ class CLICore:
             # We compare the local with the currently read deprecated version.
             checked = PyFunceble.abstracts.Version.compare(version)
 
-            if (
-                not PyFunceble.CONFIGURATION.quiet
-                and checked
-                or checked is not False
-                and not checked
-            ):
+            if checked is True and any(x in version for x in ascii_lowercase):
+                continue
+
+            if not PyFunceble.CONFIGURATION.quiet and checked is True:
                 # The quiet mode is not activated and the local version is
                 # less or equal to the currently read deprecated version.
 
@@ -526,7 +522,7 @@ class CLICore:
 
             # The quiet mode is activated.
 
-            if checked or checked is not False and not checked:
+            if checked is True:
                 # The local version is  less or equal to the currently
                 # read deprecated version.
                 print("Version deprecated.")
@@ -610,8 +606,7 @@ class CLICore:
             )
 
             if (
-                status is not None
-                and not status
+                status is False
                 and not PyFunceble.CONFIGURATION.quiet
                 and not PyFunceble.CONFIGURATION.simple
             ):
@@ -642,7 +637,49 @@ class CLICore:
 
                 # We print the message.
                 print(message)
-            elif status and not PyFunceble.CONFIGURATION.simple:
+            elif (
+                status is True
+                and any(
+                    x in upstream_version["current_version"] for x in ascii_lowercase
+                )
+                and not PyFunceble.CONFIGURATION.simple
+            ):
+                if not PyFunceble.CONFIGURATION.quiet:
+                    # The quiet mode is not activated.
+
+                    # We initiate the message we are going to return to the user.
+                    message = (
+                        Style.BRIGHT
+                        + Fore.GREEN
+                        + "A new pre-release version is available for testing!\n"
+                        + Style.RESET_ALL
+                    )  # pylint:disable=line-too-long
+                    message += (
+                        Style.BRIGHT
+                        + "Your version: "
+                        + Style.RESET_ALL
+                        + PyFunceble.VERSION
+                        + "\n"
+                    )  # pylint:disable=line-too-long
+                    message += (
+                        Style.BRIGHT
+                        + "Upstream version: "
+                        + Style.RESET_ALL
+                        + upstream_version[  # pylint:disable=line-too-long
+                            "current_version"
+                        ]
+                        + "\n"
+                    )
+
+                    # We print the message.
+                    print(message)
+                else:
+                    # The quiet mode is activated.
+
+                    # We print the message.
+                    print("New pre-release is available for testing.")
+
+            elif status is True and not PyFunceble.CONFIGURATION.simple:
                 # The current version is less that the upstream version.
 
                 if not PyFunceble.CONFIGURATION.quiet:
