@@ -34,7 +34,7 @@ Project homepage:
 License:
 ::
 
-    Copyright 2017, 2018, 2019, 2020 Nissar Chababy
+    Copyright 2017, 2018, 2019, 2020, 2021 Nissar Chababy
 
     Licensed under the Apache License, Version 2.0 (the "License");
     you may not use this file except in compliance with the License.
@@ -51,7 +51,6 @@ License:
 
 from tempfile import NamedTemporaryFile
 
-import domain2idna
 from sqlalchemy.orm.exc import NoResultFound
 
 import PyFunceble
@@ -263,9 +262,6 @@ class FileCore(CLICore):  # pylint: disable=too-many-instance-attributes
         Tests the given subject and return it's results.
         """
 
-        if PyFunceble.CONFIGURATION.idna_conversion:
-            subject = domain2idna.domain2idna(subject)
-
         if isinstance(PyFunceble.CONFIGURATION.cooldown_time, (float, int)):
             PyFunceble.sleep(PyFunceble.CONFIGURATION.cooldown_time)
 
@@ -314,7 +310,7 @@ class FileCore(CLICore):  # pylint: disable=too-many-instance-attributes
                 filename=self.file,
             ).get()
 
-        self.generate_complement_status_file(result["tested"], result["status"])
+        self.generate_complement_status_file(result["given"], result["status"])
         self.save_into_database(result, self.file)
 
         return result
@@ -333,34 +329,46 @@ class FileCore(CLICore):  # pylint: disable=too-many-instance-attributes
             PyFunceble.LOGGER.debug(f"Ignored {subject} because not true.")
             return True
 
+        PyFunceble.LOGGER.debug(f"Continue. {subject} evaluates to {True}.")
+
         if subject.startswith(PyFunceble.converter.File.comment_sign):
             PyFunceble.LOGGER.debug(
                 f"Ignored {subject} because it starts with comment sign."
             )
             return True
 
-        if auto_continue_db and subject in auto_continue_db.get_already_tested():
+        PyFunceble.LOGGER.debug(
+            f"Continue. {subject} does not starts with {PyFunceble.converter.File.comment_sign}."
+        )
+
+        if auto_continue_db and subject in auto_continue_db:
             PyFunceble.LOGGER.debug(
                 f"Ignored {subject} because it is into the list of already tested (autocontinue)."
             )
             return True
 
-        if (
-            not ignore_inactive_db_check
-            and inactive_db
-            and subject in inactive_db.get_already_tested()
-        ):
+        PyFunceble.LOGGER.debug(
+            f"Continue. {subject} is not into the list of already tested (autocontinue)."
+        )
+
+        if not ignore_inactive_db_check and inactive_db and subject in inactive_db:
             PyFunceble.LOGGER.debug(
                 f"Ignored {subject} because it is into the list of already tested (inactive_db)."
             )
             return True
 
+        PyFunceble.LOGGER.debug(
+            f"Continue. {subject} is not into the list of already tested (inactive_db)."
+        )
+
         if PyFunceble.helpers.Regex(cls.regex_ignore).match(
             subject, return_match=False
         ):
             PyFunceble.LOGGER.debug(f"Ignored {subject} because it match our regex.")
             return True
 
+        PyFunceble.LOGGER.debug(f"Continue. {subject} does not match our regex.")
+
         if (
             not PyFunceble.CONFIGURATION.local
             and PyFunceble.Check(subject).is_reserved_ip()
@@ -370,6 +378,8 @@ class FileCore(CLICore):  # pylint: disable=too-many-instance-attributes
             )
             return True
 
+        PyFunceble.LOGGER.debug(f"Continue. {subject} is not a reserved IP.")
+
         if PyFunceble.CONFIGURATION.filter and not PyFunceble.helpers.Regex(
             PyFunceble.CONFIGURATION.filter
         ).match(subject, return_match=False):
@@ -379,6 +389,8 @@ class FileCore(CLICore):  # pylint: disable=too-many-instance-attributes
             )
             return True
 
+        PyFunceble.LOGGER.debug(f"Continue. {subject} (possibly) match a filter.")
+
         return False
 
     def post_test_treatment(
@@ -396,22 +408,22 @@ class FileCore(CLICore):  # pylint: disable=too-many-instance-attributes
         """
 
         if auto_continue_db:
-            auto_continue_db.add(test_output["tested"], test_output["status"])
+            auto_continue_db.add(test_output["given"], test_output["status"])
 
         if test_output["status"].lower() in self.list_of_up_statuses:
             if mining:
                 mining.mine(test_output["tested"], file_content_type)
 
-            if inactive_db and test_output["tested"] in inactive_db:
+            if inactive_db and test_output["given"] in inactive_db:
                 PyFunceble.output.Generate(
-                    test_output["tested"],
+                    test_output["given"],
                     f"file_{file_content_type}",
                     PyFunceble.STATUS.official.up,
                 ).analytic_file("suspicious")
 
-                inactive_db.remove(test_output["tested"])
+                inactive_db.remove(test_output["given"])
         elif inactive_db:
-            inactive_db.add(test_output["tested"], test_output["status"])
+            inactive_db.add(test_output["given"], test_output["status"])
 
         if (
             auto_continue_db
@@ -420,9 +432,9 @@ class FileCore(CLICore):  # pylint: disable=too-many-instance-attributes
         ):
             if "complements" in auto_continue_db.database:
 
-                while test_output["tested"] in auto_continue_db.database["complements"]:
+                while test_output["given"] in auto_continue_db.database["complements"]:
                     auto_continue_db.database["complements"].remove(
-                        test_output["tested"]
+                        test_output["given"]
                     )
                     auto_continue_db.save()
 
@@ -444,7 +456,7 @@ class FileCore(CLICore):  # pylint: disable=too-many-instance-attributes
             and PyFunceble.CONFIGURATION.multiprocess
         ):
             generate = PyFunceble.output.Generate(
-                test_output["tested"],
+                test_output["given"],
                 f"file_{self.file_type}",
                 test_output["status"],
                 source=test_output["status_source"],
@@ -518,6 +530,8 @@ class FileCore(CLICore):  # pylint: disable=too-many-instance-attributes
             subjects = PyFunceble.converter.AdBlock(
                 line, aggressive=PyFunceble.CONFIGURATION.aggressive
             ).get_converted()
+        elif PyFunceble.CONFIGURATION.rpz:
+            subjects = PyFunceble.converter.RPZFile(line).get_converted()
         else:
             subjects = PyFunceble.converter.File(line).get_converted()
 
