@@ -35,7 +35,7 @@ License:
 ::
 
 
-    Copyright 2017, 2018, 2019, 2020 Nissar Chababy
+    Copyright 2017, 2018, 2019, 2020, 2021 Nissar Chababy
 
     Licensed under the Apache License, Version 2.0 (the "License");
     you may not use this file except in compliance with the License.
@@ -56,7 +56,6 @@ from multiprocessing import Manager, Pipe, Process, active_children
 from tempfile import NamedTemporaryFile
 from traceback import format_exc
 
-import domain2idna
 from colorama import Fore, Style
 from colorama import init as initiate_colorama
 
@@ -168,9 +167,6 @@ class MultiprocessCore(
 
         PyFunceble.INTERN.update(intern)
 
-        if PyFunceble.CONFIGURATION.idna_conversion:
-            subject = domain2idna.domain2idna(subject)
-
         if not self.should_be_ignored(
             subject,
             self.autocontinue,
@@ -196,7 +192,7 @@ class MultiprocessCore(
                     subject, complete=True, is_parent=False, db_file_name=self.file
                 ).availability(file_content_type)
 
-            self.generate_complement_status_file(result["tested"], result["status"])
+            self.generate_complement_status_file(result["given"], result["status"])
             self.save_into_database(result, self.file)
 
             if manager_data is not None:
@@ -247,7 +243,7 @@ class MultiprocessCore(
                 )
 
                 if tracker:
-                    tracker.add_position(len(test_output["tested"]))
+                    tracker.add_position(len(test_output["given"]))
 
             manager_data[:] = []
 
@@ -278,17 +274,21 @@ class MultiprocessCore(
                     _, traceback = process.exception
 
                     # We print the traceback.
-                    print(traceback)
-                    PyFunceble.LOGGER.error(traceback)
+                    print(f"\n{traceback}")
 
                     exception_present = True
 
+                    PyFunceble.LOGGER.error(traceback)
+
                 if exception_present:
                     # We kill the process.
                     process.terminate()
+
             except AttributeError:
                 continue
 
+        processes[:] = []
+
         if exception_present:
             # We finally exit.
             self.__merge_processes_data(manager_data)
@@ -300,11 +300,11 @@ class MultiprocessCore(
         Starts a new process.
         """
 
-        if subject in self.autocontinue:
-            if self.autosave.authorized or PyFunceble.CONFIGURATION.print_dots:
-                PyFunceble.LOGGER.info(f"Skipped {subject!r}: already tested.")
-                print(".", end="")
-
+        if subject in self.autocontinue and (
+            self.autosave.authorized or PyFunceble.CONFIGURATION.print_dots
+        ):
+            PyFunceble.LOGGER.info(f"Skipped {subject!r}: already tested.")
+            print(".", end="")
         else:
             original_config = PyFunceble.CONFIGURATION.copy()
             original_intern = PyFunceble.INTERN.copy()
@@ -335,6 +335,10 @@ class MultiprocessCore(
 
             PyFunceble.INTERN.update(original_intern)
 
+            return process
+
+        return None
+
     def __process_live_merging(self, finished, manager_data, tracker):
         """
         Processes the live merging.
@@ -385,6 +389,7 @@ class MultiprocessCore(
 
         minimum_position = tracker.get_position() if tracker else 0
         file_position = 0
+        processes = []
 
         while True:
             while (
@@ -419,10 +424,12 @@ class MultiprocessCore(
 
                     if isinstance(subjects, list):
                         for subject in subjects:
-                            self.__start_process(
-                                subject,
-                                manager_data,
-                                ignore_inactive_db_check=ignore_inactive_db_check,
+                            processes.append(
+                                self.__start_process(
+                                    subject,
+                                    manager_data,
+                                    ignore_inactive_db_check=ignore_inactive_db_check,
+                                )
                             )
 
                             if index != "funilrys":
@@ -430,10 +437,12 @@ class MultiprocessCore(
                                 # the mining database.
                                 self.mining.remove(index, subject)
                     else:
-                        self.__start_process(
-                            subjects,
-                            manager_data,
-                            ignore_inactive_db_check=ignore_inactive_db_check,
+                        processes.append(
+                            self.__start_process(
+                                subjects,
+                                manager_data,
+                                ignore_inactive_db_check=ignore_inactive_db_check,
+                            )
                         )
 
                         if index != "funilrys":
@@ -449,7 +458,7 @@ class MultiprocessCore(
                     finished = True
                     break
 
-            self.__check_exception(active_children(), manager_data)
+            self.__check_exception(processes, manager_data)
 
             while len(
                 active_children()
