@@ -35,7 +35,7 @@ License:
 ::
 
 
-    Copyright 2017, 2018, 2019, 2020 Nissar Chababy
+    Copyright 2017, 2018, 2019, 2020, 2021 Nissar Chababy
 
     Licensed under the Apache License, Version 2.0 (the "License");
     you may not use this file except in compliance with the License.
@@ -50,7 +50,6 @@ License:
     limitations under the License.
 """
 
-from datetime import datetime
 from multiprocessing import active_children
 
 from colorama import Fore, Style
@@ -62,39 +61,14 @@ import PyFunceble
 from ..schemas.file import File
 from ..schemas.status import Status
 from ..schemas.whois_record import WhoisRecord
+from .base import MigrationBase
 
 
-class CleanupOldTables:
+class CleanupOldTables(MigrationBase):
     """
     Provides the interface which is in charge of cleaning the database.
-
-    :param credentials:
-        A credentials object.
     """
 
-    old_tables = [
-        "pyfunceble_auto_continue",
-        "pyfunceble_inactive",
-        "pyfunceble_mining",
-        "pyfunceble_tested",
-        "pyfunceble_whois",
-    ]
-
-    def __init__(self, credentials):
-        self.credentials = credentials
-
-        self.autosave = PyFunceble.engine.AutoSave()
-
-    @property
-    def authorized(self):
-        """
-        Provides the authorization to run.
-        """
-
-        return PyFunceble.CONFIGURATION.db_type in ["mysql", "mariadb"] and any(
-            [self.does_table_exists(x) for x in self.old_tables]
-        )
-
     @classmethod
     def __get_rows(cls, statement, limit=20):
         """
@@ -114,64 +88,6 @@ class CleanupOldTables:
             for result in db_result:
                 yield result
 
-    def does_table_exists(self, table_name):
-        """
-        Checks if the table exists.
-
-        :param str table_name:
-            The name of the table to check.
-        """
-
-        with PyFunceble.engine.database.loader.session.Session() as db_session:
-            statement = (
-                "SELECT COUNT(*) "
-                "FROM information_schema.tables "
-                "WHERE table_schema = :database_name "
-                "AND table_name = :table_name "
-            )
-
-            result = db_session.execute(
-                statement,
-                {
-                    "database_name": self.credentials["name"],
-                    "table_name": table_name,
-                },
-            )
-
-            result = dict(result.fetchone())
-
-        if result["COUNT(*)"] != 1:
-            return False
-        return True
-
-    @classmethod
-    def __wait_for_all_process_to_finish(cls):
-        """
-        Wait until all migration process finished.
-        """
-
-        if PyFunceble.CONFIGURATION.multiprocess:
-            while "Migration" in " ".join(
-                [x.name for x in reversed(active_children())]
-            ):
-                continue
-
-    def __write_file_for_autocontinue(self):
-        """
-        Writes a file in order to force the CI engine to continue.
-        """
-
-        if self.autosave.authorized:
-            # Ensure that the output directory exist.
-            PyFunceble.output.Constructor()
-            with open(
-                f"{PyFunceble.OUTPUT_DIRECTORY}"
-                f"{PyFunceble.abstracts.Infrastructure.CI_MIGRATION_TRIGGER_FILE}",
-                "w",
-                encoding="utf-8",
-            ) as file_stream:
-                file_stream.write(datetime.utcnow().isoformat())
-
     @classmethod
     def __process_migration(cls, action_method, data):
         """
@@ -206,11 +122,47 @@ class CleanupOldTables:
 
         PyFunceble.LOGGER.debug(f"Switching:\n{data}")
         with PyFunceble.engine.database.loader.session.Session() as db_session:
-            # pylint: disable=no-member
             try:
                 file = (
                     db_session.query(File).filter(File.path == data["file_path"]).one()
                 )
+
+                # pylint: disable=protected-access
+                previously_saved = (
+                    file.subjects.filter(Status.tested == data["tested"])
+                    .filter(Status._status == data["_status"])
+                    .filter(Status.status == data["status"])
+                    .filter(Status._status_source == data["_status_source"])
+                    .filter(Status.status_source == data["status_source"])
+                    .filter(
+                        Status.domain_syntax_validation
+                        == data["domain_syntax_validation"]
+                    )
+                    .filter(Status.expiration_date == data["expiration_date"])
+                    .filter(Status.http_status_code == data["http_status_code"])
+                    .filter(
+                        Status.ipv4_range_syntax_validation
+                        == data["ipv4_range_syntax_validation"]
+                    )
+                    .filter(
+                        Status.ipv4_syntax_validation == data["ipv4_syntax_validation"]
+                    )
+                    .filter(
+                        Status.ipv6_range_syntax_validation
+                        == data["ipv6_range_syntax_validation"]
+                    )
+                    .filter(
+                        Status.ipv6_syntax_validation == data["ipv6_syntax_validation"]
+                    )
+                    .filter(
+                        Status.subdomain_syntax_validation
+                        == data["subdomain_syntax_validation"]
+                    )
+                    .filter(
+                        Status.url_syntax_validation == data["url_syntax_validation"]
+                    )
+                    .all()
+                )
             except NoResultFound:
                 file = File(path=data["file_path"])
 
@@ -218,36 +170,36 @@ class CleanupOldTables:
                 db_session.commit()
                 db_session.refresh(file)
 
-        status = Status(
-            file_id=file.id,
-            created=data["created"],
-            modified=data["modified"],
-            tested=data["tested"],
-            _status=data["_status"],
-            status=data["status"],
-            _status_source=data["_status_source"],
-            status_source=data["status_source"],
-            domain_syntax_validation=data["domain_syntax_validation"],
-            expiration_date=data["expiration_date"],
-            http_status_code=data["http_status_code"],
-            ipv4_range_syntax_validation=data["ipv4_range_syntax_validation"],
-            ipv4_syntax_validation=data["ipv4_syntax_validation"],
-            ipv6_range_syntax_validation=data["ipv6_range_syntax_validation"],
-            ipv6_syntax_validation=data["ipv6_syntax_validation"],
-            subdomain_syntax_validation=data["subdomain_syntax_validation"],
-            url_syntax_validation=data["url_syntax_validation"],
-            is_complement=False,
-            test_completed=True,
-        )
+                previously_saved = []
 
-        with PyFunceble.engine.database.loader.session.Session() as db_session:
-            # pylint: disable=no-member
-            try:
-                db_session.add(status)
-                db_session.commit()
-                db_session.refresh(status)
-            except IntegrityError:
-                pass
+            if not previously_saved:
+                status = Status(
+                    file_id=file.id,
+                    created=data["created"],
+                    modified=data["modified"],
+                    tested=data["tested"],
+                    _status=data["_status"],
+                    status=data["status"],
+                    _status_source=data["_status_source"],
+                    status_source=data["status_source"],
+                    domain_syntax_validation=data["domain_syntax_validation"],
+                    expiration_date=data["expiration_date"],
+                    http_status_code=data["http_status_code"],
+                    ipv4_range_syntax_validation=data["ipv4_range_syntax_validation"],
+                    ipv4_syntax_validation=data["ipv4_syntax_validation"],
+                    ipv6_range_syntax_validation=data["ipv6_range_syntax_validation"],
+                    ipv6_syntax_validation=data["ipv6_syntax_validation"],
+                    subdomain_syntax_validation=data["subdomain_syntax_validation"],
+                    url_syntax_validation=data["url_syntax_validation"],
+                    is_complement=False,
+                    test_completed=True,
+                )
+
+                try:
+                    file.subjects.append(status)
+                    db_session.commit()
+                except IntegrityError:
+                    pass
 
         with PyFunceble.engine.database.loader.session.Session() as db_session:
             statement = "DELETE FROM pyfunceble_tested WHERE id = :status_id"
@@ -270,14 +222,11 @@ class CleanupOldTables:
             statement = "SELECT * FROM pyfunceble_tested"
 
             for data in self.__get_rows(statement):
-                if self.autosave.is_time_exceed():
-                    self.__wait_for_all_process_to_finish()
-                    self.__write_file_for_autocontinue()
-                    self.autosave.process()
+                self.handle_autosaving()
 
                 self.__process_migration(self.__tested_migration, data)
 
-            self.__wait_for_all_process_to_finish()
+            self.wait_for_all_process_to_finish()
 
             PyFunceble.LOGGER.info("Finished to switch (tested) SQLAlchemy.")
 
@@ -300,27 +249,22 @@ class CleanupOldTables:
                 db_session.commit()
                 db_session.refresh(file)
 
-        with PyFunceble.engine.database.loader.session.Session() as db_session:
-            # pylint: disable=no-member
+            status_found_in_db = False
+
             try:
-                status = (
-                    db_session.query(Status)
-                    .join(File)
-                    .filter(File.path == data["file_path"])
-                    .filter(Status.tested == data["subject"])
-                    .one()
-                )
+                status = file.subjects.filter(Status.tested == data["subject"]).one()
+                status_found_in_db = True
             except NoResultFound:
                 status = Status(
                     tested=data["subject"], status=data["subject"], file_id=file.id
                 )
 
-        status.is_complement = data["is_complement"]
+            status.is_complement = data["is_complement"]
 
-        with PyFunceble.engine.database.loader.session.Session() as db_session:
-            # pylint: disable=no-member
             try:
-                db_session.add(status)
+                if not status_found_in_db:
+                    file.subjects.append(status)
+
                 db_session.commit()
             except IntegrityError:
                 pass
@@ -347,14 +291,11 @@ class CleanupOldTables:
             statement = "SELECT * FROM pyfunceble_auto_continue"
 
             for data in self.__get_rows(statement):
-                if self.autosave.is_time_exceed():
-                    self.__wait_for_all_process_to_finish()
-                    self.__write_file_for_autocontinue()
-                    self.autosave.process()
+                self.handle_autosaving()
 
                 self.__process_migration(self.__autocontinue_migration, data)
 
-            self.__wait_for_all_process_to_finish()
+            self.wait_for_all_process_to_finish()
             PyFunceble.LOGGER.info("Starting to switch (autocontinue) SQLAlchemy.")
 
     def __whois_migration(self, data):
@@ -422,14 +363,11 @@ class CleanupOldTables:
             statement = "SELECT * FROM pyfunceble_whois"
 
             for data in self.__get_rows(statement):
-                if self.autosave.is_time_exceed():
-                    self.__wait_for_all_process_to_finish()
-                    self.__write_file_for_autocontinue()
-                    self.autosave.process()
+                self.handle_autosaving()
 
                 self.__process_migration(self.__whois_migration, data)
 
-            self.__wait_for_all_process_to_finish()
+            self.wait_for_all_process_to_finish()
 
             PyFunceble.LOGGER.info("Starting to switch (whois) SQLAlchemy.")
 
