@@ -35,7 +35,7 @@ License:
 ::
 
 
-    Copyright 2017, 2018, 2019, 2020 Nissar Chababy
+    Copyright 2017, 2018, 2019, 2020, 2021 Nissar Chababy
 
     Licensed under the Apache License, Version 2.0 (the "License");
     you may not use this file except in compliance with the License.
@@ -65,7 +65,7 @@ class Logs:
 
     def __init__(self, output=None):
         self.output = output
-        self.current_time = str(datetime.now().timestamp())
+        self.current_time = str(datetime.utcnow().timestamp())
 
     @classmethod
     def _get_content(cls, file):
