@@ -35,7 +35,7 @@ License:
 ::
 
 
-    Copyright 2017, 2018, 2019, 2020 Nissar Chababy
+    Copyright 2017, 2018, 2019, 2020, 2021 Nissar Chababy
 
     Licensed under the Apache License, Version 2.0 (the "License");
     you may not use this file except in compliance with the License.
@@ -59,9 +59,11 @@ import PyFunceble
 
 class ExtraRules:  # pylint: disable=too-few-public-methods # pragma: no cover
     """
-    Manage some extra rules.,
+    Manage some extra rules.
 
-    :param str subject: The subject we are working with.
+    :param status_obj:
+        The status obj to handle.
+    :type status_obj: :py:class:`PyFunceble.status.status.Status`
 
     :param str subject_type:
         The type of the subject we are working with.
@@ -74,9 +76,9 @@ class ExtraRules:  # pylint: disable=too-few-public-methods # pragma: no cover
     :type http_status_code: str|int
     """
 
-    def __init__(self, subject, subject_type, http_status_code):
-        # We share the subject we are working with.
-        self.subject = subject
+    def __init__(self, status_obj, subject_type, http_status_code):
+        # We share the status obj we are working with.
+        self.status = status_obj
         # We share the subject type.
         self.subject_type = subject_type
         # We share the status code.
@@ -92,21 +94,25 @@ class ExtraRules:  # pylint: disable=too-few-public-methods # pragma: no cover
 
         # We set a list of regex and methods to call if matched.
         self.regexes_active_to_inactive_potentially_down = {
-            r"\.blogspot\.": self.__blogspot,
-            r"\.canalblog\.com$": self.__special_down_404,
-            r"\.github\.io$": self.__special_down_404,
-            r"\.liveadvert\.com$": self.__special_down_404,
-            r"\.skyrock\.com$": self.__special_down_404,
-            r"\.tumblr\.com$": self.__special_down_404,
+            r"\.000webhostapp\.com": [self.__special_down_410],
+            r"\.angelfire\.com$": [self.__special_down_404],
+            r"\.blogspot\.": [self.__blogspot],
+            r"\.canalblog\.com$": [self.__special_down_404],
+            r"\.github\.io$": [self.__special_down_404],
+            r"\.hpg.com.br$": [self.__special_down_404],
+            r"\.liveadvert\.com$": [self.__special_down_404],
+            r"\.skyrock\.com$": [self.__special_down_404],
+            r"\.tumblr\.com$": [self.__special_down_404],
+            r"\.wix\.com$": [self.__special_down_404],
         }
 
         # We set a list of regex and methods to call if matched.
         self.regexes_active_to_inactive_potentially_up = {
-            r"\.blogspot\.": self.__blogspot,
-            r"\.wordpress\.com$": self.__wordpress_dot_com,
+            r"\.blogspot\.": [self.__blogspot],
+            r"\.wordpress\.com$": [self.__wordpress_dot_com],
         }
 
-        PyFunceble.LOGGER.debug(f"[{self.subject}] Headers:\n{self.headers}")
+        PyFunceble.LOGGER.debug(f"[{self.status.given}] Headers:\n{self.headers}")
 
     @classmethod
     def __special_down(cls):
@@ -132,6 +138,19 @@ class ExtraRules:  # pylint: disable=too-few-public-methods # pragma: no cover
             return PyFunceble.STATUS.official.down, "SPECIAL"
         return None
 
+    def __special_down_410(self):
+        """
+        Set what we return for the SPECIAL status de-escalation
+        when the 410 status code is caught.
+
+        :return: :code:`(new status, new source)`
+        :rtype: tuple
+        """
+
+        if self.status_code == 410:
+            return PyFunceble.STATUS.official.down, "SPECIAL"
+        return None
+
     @classmethod
     def __special_up(cls):
         """
@@ -172,12 +191,12 @@ class ExtraRules:  # pylint: disable=too-few-public-methods # pragma: no cover
             # The element we are testing is a domain.
 
             # We construct the url to get.
-            url_to_get = "http://%s" % self.subject
+            url_to_get = "http://%s" % self.status.tested
         elif self.subject_type in ["url", "file_url"]:
             # The element we are testing is a URL.
 
             # We construct the url to get.
-            url_to_get = self.subject
+            url_to_get = self.status.tested
         else:
             raise ValueError("Given subject type not registered.")
 
@@ -202,7 +221,7 @@ class ExtraRules:  # pylint: disable=too-few-public-methods # pragma: no cover
                     # * Something in the document match the currently read regex.
 
                     PyFunceble.LOGGER.info(
-                        "[{self.subject}] Switching status according to blogspot rule."
+                        f"[{self.status.given}] Switching status according to blogspot rule."
                     )
 
                     # We update the status and source.
@@ -237,7 +256,7 @@ class ExtraRules:  # pylint: disable=too-few-public-methods # pragma: no cover
         try:
             # We get the content of the page.
             wordpress_com_content = PyFunceble.REQUESTS.get(
-                "http://{}:80".format(self.subject),
+                "http://{}:80".format(self.status.tested),
                 headers=self.headers,
                 timeout=PyFunceble.CONFIGURATION.timeout,
                 verify=PyFunceble.CONFIGURATION.verify_ssl_certificate,
@@ -248,7 +267,7 @@ class ExtraRules:  # pylint: disable=too-few-public-methods # pragma: no cover
                 # The marker is into the page content.
 
                 PyFunceble.LOGGER.info(
-                    "[{self.subject}] Switching status according to wordpress_dot_com rule."
+                    f"[{self.status.given}] Switching status according to wordpress_dot_com rule."
                 )
 
                 # We return the new status and source.
@@ -259,7 +278,9 @@ class ExtraRules:  # pylint: disable=too-few-public-methods # pragma: no cover
         # We return None, there is no changes.
         return None
 
-    def __handle_potentially_inactive(self, previous_state):
+    def __handle_potentially_inactive(
+        self, previous_state
+    ):  # pylint: disable=too-many-nested-blocks
         """
         Handle the potentially inactive case.
 
@@ -280,34 +301,33 @@ class ExtraRules:  # pylint: disable=too-few-public-methods # pragma: no cover
             # * The extracted http status code is in the list of
             #   potentially down list.
 
-            # We generate the analytics files.
             PyFunceble.output.Generate(
-                self.subject, self.subject_type, previous_state
+                self.status.given, self.subject_type, previous_state
             ).analytic_file("potentially_down")
 
             if not PyFunceble.CONFIGURATION.no_special:
-                # We are authorized to play with the SPEICIAL rules.
+                # We are authorized to play with the SPECIAL rules.
 
-                for regx in self.regexes_active_to_inactive_potentially_down:
-                    # We loop through the list of available regex.
+                for (
+                    regx,
+                    methods,
+                ) in self.regexes_active_to_inactive_potentially_down.items():
+                    for method in methods:
+                        if PyFunceble.helpers.Regex(regx).match(
+                            self.status.tested, return_match=False
+                        ):
+                            # The element we are currently testing match the
+                            # regex we are currently reading.
 
-                    if PyFunceble.helpers.Regex(regx).match(
-                        self.subject, return_match=False
-                    ):
-                        # The element we are currently testing match the
-                        # regex we are currently reading.
+                            # We get the output of the function associated
+                            # with the regex.
+                            output = method()
 
-                        # We get the output of the function associated
-                        # with the regex.
-                        output = self.regexes_active_to_inactive_potentially_down[
-                            regx
-                        ]()
+                            if output is not None:
+                                # The output is not None.
 
-                        if output is not None:
-                            # The output is not None.
-
-                            # We return the new source and state.
-                            return output
+                                # We return the new source and state.
+                                return output
 
         # We return None, there is no changes.
         return None
@@ -325,26 +345,30 @@ class ExtraRules:  # pylint: disable=too-few-public-methods # pragma: no cover
         if (
             PyFunceble.HTTP_CODE.active
             and self.status_code in PyFunceble.HTTP_CODE.list.potentially_up
+            and not PyFunceble.CONFIGURATION.no_special
         ):
             # * The http status code request is activated.
             # and
             # * The extracted http status code is into the list of potentially up codes.
+            # and
+            # * We are authorized to play with the SPECIAL rules.
 
-            if not PyFunceble.CONFIGURATION.no_special:
-                # We are authorized to play with the SPEICIAL rules.
-
-                for regx in self.regexes_active_to_inactive_potentially_up:
-                    # We loop through the list of available regex.
+            for (
+                regx,
+                methods,
+            ) in self.regexes_active_to_inactive_potentially_up.items():
+                # We loop through the list of available regex.
 
+                for method in methods:
                     if PyFunceble.helpers.Regex(regex=regx).match(
-                        self.subject, return_match=False
+                        self.status.tested, return_match=False
                     ):
                         # The element we are currently testing match the
                         # regex we are currently reading.
 
                         # We get the output of the function associated
                         # with the regex.
-                        output = self.regexes_active_to_inactive_potentially_up[regx]()
+                        output = method()
 
                         if output is not None:
                             # The output is not None.
@@ -374,14 +398,14 @@ class ExtraRules:  # pylint: disable=too-few-public-methods # pragma: no cover
 
                 # We generate the analytics files.
                 PyFunceble.output.Generate(
-                    self.subject, self.subject_type, previous_state
+                    self.status.given, self.subject_type, previous_state
                 ).analytic_file(PyFunceble.STATUS.official.up)
 
                 if previous_state.lower() not in PyFunceble.STATUS.list.up:
                     # And we return the new status and source
 
                     PyFunceble.LOGGER.info(
-                        "[{self.subject}] Switching status according to status code rule."
+                        f"[{self.status.given}] Switching status according to status code rule."
                     )
 
                     return self.__http_status_code_up()
@@ -391,13 +415,13 @@ class ExtraRules:  # pylint: disable=too-few-public-methods # pragma: no cover
 
                 # We generate the analytics files.
                 PyFunceble.output.Generate(
-                    self.subject, self.subject_type, previous_state
+                    self.status.given, self.subject_type, previous_state
                 ).analytic_file("potentially_up")
 
                 if previous_state.lower() not in PyFunceble.STATUS.list.up:
 
                     PyFunceble.LOGGER.info(
-                        "[{self.subject}] Switching status according to status code rule."
+                        f"[{self.status.given}] Switching status according to status code rule."
                     )
 
                     # And we return the new status and source
@@ -409,11 +433,11 @@ class ExtraRules:  # pylint: disable=too-few-public-methods # pragma: no cover
             ):
                 # We generate the analytics files.
                 PyFunceble.output.Generate(
-                    self.subject, self.subject_type, previous_state
+                    self.status.given, self.subject_type, previous_state
                 ).analytic_file("potentially_up")
 
                 PyFunceble.LOGGER.info(
-                    "[{self.subject}] Switching status according to status code rule."
+                    f"[{self.status.given}] Switching status according to status code rule."
                 )
 
                 # And we return the new status and source
@@ -427,7 +451,7 @@ class ExtraRules:  # pylint: disable=too-few-public-methods # pragma: no cover
 
                 # We generate the analytics files.
                 PyFunceble.output.Generate(
-                    self.subject, self.subject_type, previous_state
+                    self.status.given, self.subject_type, previous_state
                 ).analytic_file("potentially_down")
         except KeyError:
             PyFunceble.LOGGER.exception()
@@ -448,10 +472,10 @@ class ExtraRules:  # pylint: disable=too-few-public-methods # pragma: no cover
         if (
             not PyFunceble.CONFIGURATION.no_special
             and PyFunceble.CONFIGURATION.use_reputation_data
-            and self.subject in PyFunceble.lookup.IPv4Reputation()
+            and self.status.tested in PyFunceble.lookup.IPv4Reputation()
         ):
             PyFunceble.LOGGER.info(
-                "[{self.subject}] Switching status according to reputation rule."
+                f"[{self.status.given}] Switching status according to reputation rule."
             )
 
             return self.__special_up()
@@ -469,14 +493,14 @@ class ExtraRules:  # pylint: disable=too-few-public-methods # pragma: no cover
 
         if (
             not PyFunceble.CONFIGURATION.no_special
-            and PyFunceble.Check(self.subject).is_ip_range()
+            and PyFunceble.Check(self.status.tested).is_ip_range()
         ):
             # * We can run/check the special rule.
             # and
             # * The element we are currently testing is an IP range.
 
             PyFunceble.LOGGER.info(
-                "[{self.subject}] Switching status according to IP range rule."
+                f"[{self.status.given}] Switching status according to IP range rule."
             )
 
             # We return the new status and source.
@@ -485,13 +509,16 @@ class ExtraRules:  # pylint: disable=too-few-public-methods # pragma: no cover
         # We return None, there is no changes.
         return None
 
-    def handle(
-        self, previous_state, previous_source
-    ):  # pylint:disable= too-many-return-statements
+    def handle(self):  # pylint:disable= too-many-return-statements
         """
         Globally handle the case of the currently tested domain.
         """
 
+        previous_state, previous_source = (
+            self.status["_status"],
+            self.status["_status_source"],
+        )
+
         # We preset the new status and the source to None.
         new_status = None
         source = None
