@@ -35,7 +35,7 @@ License:
 ::
 
 
-    Copyright 2017, 2018, 2019, 2020 Nissar Chababy
+    Copyright 2017, 2018, 2019, 2020, 2021 Nissar Chababy
 
     Licensed under the Apache License, Version 2.0 (the "License");
     you may not use this file except in compliance with the License.
@@ -106,7 +106,7 @@ class Url(GathererBase):
             ] = self.status.status = PyFunceble.STATUS.official.invalid
 
         PyFunceble.output.Generate(
-            self.subject,
+            self.status.given,
             self.subject_type,
             self.status.status,
             source=self.status.status_source,
@@ -119,4 +119,4 @@ class Url(GathererBase):
             )
         )
 
-        PyFunceble.LOGGER.debug(f"[{self.subject}] State:\n{self.status.get()}")
+        PyFunceble.LOGGER.debug(f"[{self.status.given}] State:\n{self.status.get()}")
